<?php 
/**
 * 宝塔面板站点操作类库
 * @author 二次开发：阿良 or Youngxj ，三次开发：阿铭
 * @link https://www.bt.cn/api-doc.pdf
 * @version 1.3.5
 * @example
 * $bt = new Bt('http://127.0.0.1/8888','xxxxxxxxxxxxxxxx');
 * echo $bt->GetSystemTotal();//获取系统基础统计
 */
namespace Bt;
class Api{
    /**
     * 配置变量
     * @var array
     */
    private $config=array(
        'ENCODE'=>'utf-8',//输出编码
        'BT_KEY'=>'', //接口密钥
        'BT_PANEL'=>'http://127.0.0.1:8989',//面板地址
        # 系统状态相关接口
        'GetSystemTotal' => '/system?action=GetSystemTotal',	   //获取系统基础统计
        'GetDiskInfo' => '/system?action=GetDiskInfo',			     //获取磁盘分区信息
        'GetNetWork' => '/system?action=GetNetWork',			       //获取实时状态信息(CPU、内存、网络、负载)
        'GetTaskCount' => '/ajax?action=GetTaskCount',			     //检查是否有安装任务
        'UpdatePanel' => '/ajax?action=UpdatePanel',			       //检查面板更新
        # 网站管理相关接口
        'Websites' => '/data?action=getData&table=sites',		     //获取网站列表
        'Webtypes' => '/site?action=get_site_types',			       //获取网站分类
        'GetPHPVersion' => '/site?action=GetPHPVersion',		     //获取已安装的 PHP 版本列表
        'GetSitePHPVersion' => '/site?action=GetSitePHPVersion', //获取指定网站运行的PHP版本
        'SetPHPVersion' => '/site?action=SetPHPVersion',         //修改指定网站的PHP版本
        'SetHasPwd' => '/site?action=SetHasPwd',                 //开启并设置网站密码访问
        'CloseHasPwd' => '/site?action=CloseHasPwd',             //关闭网站密码访问
        'GetDirUserINI' => '/site?action=GetDirUserINI',         //获取网站几项开关（防跨站、日志、密码访问）
        'WebAddSite' => '/site?action=AddSite',					         //创建网站
        'WebDeleteSite' => '/site?action=DeleteSite',			       //删除网站
        'WebSiteStop' => '/site?action=SiteStop',				         //停用网站
        'WebSiteStart' => '/site?action=SiteStart',				       //启用网站
        'WebSetEdate' => '/site?action=SetEdate',				         //设置网站有效期
        'WebSetPs' => '/data?action=setPs&table=sites',			     //修改网站备注
        'WebBackupList' => '/data?action=getData&table=backup',	 //获取网站备份列表
        'WebToBackup' => '/site?action=ToBackup',				         //创建网站备份
        'WebDelBackup' => '/site?action=DelBackup',				       //删除网站备份
        'WebDoaminList' => '/data?action=getData&table=domain',	 //获取网站域名列表
        'GetDirBinding' => '/site?action=GetDirBinding',         //获取网站域名绑定二级目录信息
        'AddDirBinding' => '/site?action=AddDirBinding',         //添加网站子目录域名
        'DelDirBinding' => '/site?action=DelDirBinding',         //删除网站绑定子目录
        'GetDirRewrite' => '/site?action=GetDirRewrite',         //获取网站子目录伪静态规则
        'WebAddDomain' => '/site?action=AddDomain',				       //添加网站域名
        'WebDelDomain' => '/site?action=DelDomain',				       //删除网站域名
        'GetSiteLogs' => '/site?action=GetSiteLogs',             //获取网站日志
        'GetSecurity' => '/site?action=GetSecurity',             //获取网站盗链状态及规则信息
        'SetSecurity' => '/site?action=SetSecurity',             //设置网站盗链状态及规则信息
        'GetSSL' => '/site?action=GetSSL',                       //获取SSL状态及证书详情
        'HttpToHttps' => '/site?action=HttpToHttps',             //强制HTTPS
        'CloseToHttps' => '/site?action=CloseToHttps',           //关闭强制HTTPS
        'SetSSL' => '/site?action=SetSSL',                       //设置SSL证书
        'CloseSSLConf' => '/site?action=CloseSSLConf',           //关闭SSL
        'WebGetIndex' => '/site?action=GetIndex',                //获取网站默认文件
        'WebSetIndex' => '/site?action=SetIndex',                //设置网站默认文件
        'GetLimitNet' => '/site?action=GetLimitNet',             //获取网站流量限制信息
        'SetLimitNet' => '/site?action=SetLimitNet',             //设置网站流量限制信息
        'CloseLimitNet' => '/site?action=CloseLimitNet',         //关闭网站流量限制
        'Get301Status' => '/site?action=Get301Status',           //获取网站301重定向信息
        'Set301Status' => '/site?action=Set301Status',           //设置网站301重定向信息
        'GetRewriteList' => '/site?action=GetRewriteList',		   //获取可选的预定义伪静态列表
        'GetFileBody' => '/files?action=GetFileBody',			       //获取指定预定义伪静态规则内容(获取文件内容)
        'SaveFileBody' => '/files?action=SaveFileBody',			     //保存伪静态规则内容(保存文件内容)
        'GetProxyList' => '/site?action=GetProxyList',           //获取网站反代信息及状态
        'CreateProxy' => '/site?action=CreateProxy',             //添加网站反代信息
        'ModifyProxy' => '/site?action=ModifyProxy',             //修改网站反代信息

        # Ftp管理
        'WebFtpList' => '/data?action=getData&table=ftps',       //获取FTP信息列表
        'SetUserPassword' => '/ftp?action=SetUserPassword',      //修改FTP账号密码
        'SetStatus' => '/ftp?action=SetStatus',                  //启用/禁用FTP

        # Sql管理
        'WebSqlList' => '/data?action=getData&table=databases',  //获取SQL信息列表
        'ResDatabasePass' => '/database?action=ResDatabasePassword',  //修改SQL账号密码
        'SQLToBackup' => '/database?action=ToBackup',            //创建sql备份
        'SQLDelBackup' => '/database?action=DelBackup',          //删除sql备份
        'download' => '/download?filename=',                     //下载备份文件(目前暂停使用)

        # 插件管理
        'deployment' => '/plugin?action=a&name=deployment&s=GetList&type=0',       //宝塔一键部署列表
        'SetupPackage' => '/plugin?action=a&name=deployment&s=SetupPackage',       //部署任务
    );
    /**
     * 初始化
     * Api constructor.
     * @param null $bt_panel 宝塔接口地址
     * @param null $bt_key 宝塔Api密钥
     */
  	public function __construct($bt_panel = null,$bt_key = null){
        if(function_exists('config'))if(config("bt_api."))$this->config=array_merge($this->config,config("bt_api."));
  		if($bt_panel) $this->config["BT_PANEL"] = $bt_panel;
  		if($bt_key) $this->config["BT_KEY"] = $bt_key;
  	}

    /**
     * 获取系统基础统计
     * @return array|string
     */
  	public function GetSystemTotal(){
  		$url = $this->config["BT_PANEL"].$this->config["GetSystemTotal"];
  		$p_data = $this->GetKeyData();
  		$result = $this->HttpPostCookie($url,$p_data);
  		return $result;
  	}

    /**
     * 获取磁盘分区信息
     * @return array|string
     */
  	public function GetDiskInfo(){
  		$url = $this->config["BT_PANEL"].$this->config["GetDiskInfo"];
  		$p_data = $this->GetKeyData();
  		$result = $this->HttpPostCookie($url,$p_data);
  		return $result;
  	}

    /**
     * 获取实时状态信息(CPU、内存、网络、负载)
     * @return array|string
     */
  	public function GetNetWork(){
  		$url = $this->config["BT_PANEL"].$this->config["GetNetWork"];
  		$p_data = $this->GetKeyData();
  		$result = $this->HttpPostCookie($url,$p_data);
  		return $result;
  	}

    /**
     * 检查是否有安装任务
     * @return array|string
     */
  	public function GetTaskCount(){
  		$url = $this->config["BT_PANEL"].$this->config["GetTaskCount"];
  		$p_data = $this->GetKeyData();
  		$result = $this->HttpPostCookie($url,$p_data);
  		return $result;
  	}

    /**
     * 检查面板更新
     * @param bool $check
     * @param bool $force
     * @return array|string
     */
  	public function UpdatePanel($check=false,$force=false){
  		$url = $this->config["BT_PANEL"].$this->config["UpdatePanel"];
  		$p_data = $this->GetKeyData();
  		$p_data['check'] = $check;
  		$p_data['force'] = $force;
  		$result = $this->HttpPostCookie($url,$p_data);
  		return $result;
  	}

    /**
     * 获取网站列表
     * @param string $search 搜索内容
     * @param string $page 当前分页
     * @param string $limit 取出的数据行数
     * @param string $type 分类标识 -1: 分部分类 0: 默认分类
     * @param string $order 排序规则 使用 id 降序：id desc 使用名称升序：name desc
     * @param string $tojs 分页 JS 回调,若不传则构造 URI 分页连接
     * @return array|string
     */
	public function Websites($search='',$page='1',$limit='15',$type='-1',$order='id desc',$tojs=''){
		$url = $this->config["BT_PANEL"].$this->config["Websites"];
		$p_data = $this->GetKeyData();
		$p_data['p'] = $page;
		$p_data['limit'] = $limit;
		$p_data['type'] = $type;
		$p_data['order'] = $order;
		$p_data['tojs'] = $tojs;
		$p_data['search'] = $search;
		$result = $this->HttpPostCookie($url,$p_data);
		return $result;
	}

    /**
     * 获取网站FTP列表
     * @param string $search 搜索内容
     * @param string $page 当前分页
     * @param string $limit 取出的数据行数
     * @param string $type 分类标识 -1: 分部分类 0: 默认分类
     * @param string $order 排序规则 使用 id 降序：id desc 使用名称升序：name desc
     * @param string $tojs 分页 JS 回调,若不传则构造 URI 分页连接
     * @return array|string
     */
	public function WebFtpList($search='',$page='1',$limit='15',$type='-1',$order='id desc',$tojs=''){
		$url = $this->config["BT_PANEL"].$this->config["WebFtpList"];
		$p_data = $this->GetKeyData();
		$p_data['p'] = $page;
		$p_data['limit'] = $limit;
		$p_data['type'] = $type;
		$p_data['order'] = $order;
		$p_data['tojs'] = $tojs;
		$p_data['search'] = $search;
		$result = $this->HttpPostCookie($url,$p_data);
		return $result;
	}

    /**
     * 获取网站SQL列表
     * @param string $search 搜索内容
     * @param string $page 当前分页
     * @param string $limit 取出的数据行数
     * @param string $type 分类标识 -1: 分部分类 0: 默认分类
     * @param string $order 排序规则 使用 id 降序：id desc 使用名称升序：name desc
     * @param string $tojs 分页 JS 回调,若不传则构造 URI 分页连接
     * @return array|string
     */
	public function WebSqlList($search='',$page='1',$limit='15',$type='-1',$order='id desc',$tojs=''){
		$url = $this->config["BT_PANEL"].$this->config["WebSqlList"];
		$p_data = $this->GetKeyData();
		$p_data['p'] = $page;
		$p_data['limit'] = $limit;
		$p_data['type'] = $type;
		$p_data['order'] = $order;
		$p_data['tojs'] = $tojs;
		$p_data['search'] = $search;
		$result = $this->HttpPostCookie($url,$p_data);
		return $result;
	}

    /**
     * 获取所有网站分类
     * @return array|string
     */
	public function Webtypes(){
		$url = $this->config["BT_PANEL"].$this->config["Webtypes"];
		$p_data = $this->GetKeyData();
		$result = $this->HttpPostCookie($url,$p_data);
		return $result;
	}

    /**
     * 获取已安装的 PHP 版本列表
     * @return array|string
     */
	public function GetPHPVersion(){
		//拼接URL地址
		$url = $this->config["BT_PANEL"].$this->config["GetPHPVersion"];
		//准备POST数据
		$p_data = $this->GetKeyData();		//取签名
		//请求面板接口
		$result = $this->HttpPostCookie($url,$p_data);
		//解析JSON数据
		return $result;
	}

    /**
     * 修改指定网站的PHP版本
     * @param $site [type]  网站名
     * @param $php [type] PHP版本
     * @return array|string
     */
	public function SetPHPVersion($site,$php){
		
		$url = $this->config["BT_PANEL"].$this->config["SetPHPVersion"];
		$p_data = $this->GetKeyData();
		$p_data['siteName'] = $site;
		$p_data['version'] = $php;
		$result = $this->HttpPostCookie($url,$p_data);
		return $result;
	}

    /**
     * 获取指定网站运行的PHP版本
     * @param $site [type] 网站名
     * @return array|string.
     */
	public function GetSitePHPVersion($site){
		$url = $this->config["BT_PANEL"].$this->config["GetSitePHPVersion"];
		$p_data = $this->GetKeyData();
		$p_data['siteName'] = $site;
		$result = $this->HttpPostCookie($url,$p_data);
		return $result;
	}

    /**
     * 新增网站
     * @param array $infoArr
     * =============================
     *  $infoArr构成结构
     *  $webname       网站域名 json格式
     *   $path         网站路径
     *   $type_id      网站分类ID
     *   $type         网站类型
     *   $version      PHP版本
     *   $port         网站端口
     *   $ps           网站备注
     *   $ftp          网站是否开通FTP
     *   $ftp_username FTP用户名
     *   $ftp_password FTP密码
     *   $sql          网站是否开通数据库
     *   $codeing      数据库编码类型 utf8|utf8mb4|gbk|big5
     *   $datauser     数据库账号
     *   $datapassword 数据库密码
     * =============================
     * @return array|string
     */
	public function AddSite($infoArr=[]){
		$url = $this->config["BT_PANEL"].$this->config["WebAddSite"];
		//准备POST数据
		$p_data = $this->GetKeyData();		//取签名
		$p_data['webname'] = $infoArr['webname'];
		$p_data['path'] = $infoArr['path'];
		$p_data['type_id'] = $infoArr['type_id'];
		$p_data['type'] = $infoArr['type'];
		$p_data['version'] = $infoArr['version'];
		$p_data['port'] = $infoArr['port'];
		$p_data['ps'] = $infoArr['ps'];
		$p_data['ftp'] = $infoArr['ftp'];
		$p_data['ftp_username'] = $infoArr['ftp_username'];
		$p_data['ftp_password'] = $infoArr['ftp_password'];
		$p_data['sql'] = $infoArr['sql'];
		$p_data['codeing'] = $infoArr['codeing'];
		$p_data['datauser'] = $infoArr['datauser'];
		$p_data['datapassword'] = $infoArr['datapassword'];
		//请求面板接口
		$result = $this->HttpPostCookie($url,$p_data);
		//解析JSON数据
		return $result;
	}

    /**
     * 删除网站
     * @param $id [type] 网站ID
     * @param $webname [type] 网站名称
     * @param $ftp [type] 是否删除关联FTP
     * @param $database [type] 是否删除关联数据库
     * @param $path [type] 是否删除关联网站根目录
     * @return array|string
     */
	public function WebDeleteSite($id,$webname,$ftp,$database,$path){
		$url = $this->config["BT_PANEL"].$this->config["WebDeleteSite"];
		$p_data = $this->GetKeyData();
		$p_data['id'] = $id;
		$p_data['webname'] = $webname;
		$p_data['ftp'] = $ftp;
		$p_data['database'] = $database;
		$p_data['path'] = $path;
		$result = $this->HttpPostCookie($url,$p_data);
		return $result;
	}

    /**
     * 停用站点
     * @param $id [type] 网站ID
     * @param $name [type] 网站域名
     * @return array|string
     */
	public function WebSiteStop($id,$name){
		$url = $this->config["BT_PANEL"].$this->config["WebSiteStop"];
		$p_data = $this->GetKeyData();
		$p_data['id'] = $id;
		$p_data['name'] = $name;
		$result = $this->HttpPostCookie($url,$p_data);
		return $result;
	}

    /**
     * 启用网站
     * @param $id [type] 网站ID
     * @param $name [type] 网站域名
     * @return array|string
     */
	public function WebSiteStart($id,$name){
		$url = $this->config["BT_PANEL"].$this->config["WebSiteStart"];
		$p_data = $this->GetKeyData();
		$p_data['id'] = $id;
		$p_data['name'] = $name;
		$result = $this->HttpPostCookie($url,$p_data);
		return $result;
	}

    /**
     * 设置网站到期时间
     * @param $id [type]  网站ID
     * @param $edate [type]  网站到期时间 格式：2019-01-01，永久：0000-00-00
     * @return array|string
     */
	public function WebSetEdate($id,$edate){
		$url = $this->config["BT_PANEL"].$this->config["WebSetEdate"];
		$p_data = $this->GetKeyData();
		$p_data['id'] = $id;
		$p_data['edate'] = $edate;
		$result = $this->HttpPostCookie($url,$p_data);
		return $result;
	}

    /**
     * 修改网站备注
     * @param $id [type] 网站ID
     * @param $ps [type] 网站备注
     * @return array|string
     */
	public function WebSetPs($id,$ps){
		$url = $this->config["BT_PANEL"].$this->config["WebSetPs"];
		$p_data = $this->GetKeyData();
		$p_data['id'] = $id;
		$p_data['ps'] = $ps;
		$result = $this->HttpPostCookie($url,$p_data);
		return $result;
	}

    /**
     * 获取网站备份列表
     * @param number $id 网站ID
     * @param string $page 当前分页
     * @param string $limit 每页取出的数据行数
     * @param string $type 备份类型 目前固定为0
     * @param string $tojs 分页js回调若不传则构造 URI 分页连接 get_site_backup
     * @return array|string
     */
	public function WebBackupList($id,$page='1',$limit='5',$type='0',$tojs=''){
		$url = $this->config["BT_PANEL"].$this->config["WebBackupList"];
		$p_data = $this->GetKeyData();
		$p_data['p'] = $page;
		$p_data['limit'] = $limit;
		$p_data['type'] = $type;
		$p_data['tojs'] = $tojs;
		$p_data['search'] = $id;
		$result = $this->HttpPostCookie($url,$p_data);
		return $result;
	}

    /**
     * 创建网站备份
     * @param number $id 网站ID
     * @return array|string
     */
	public function WebToBackup($id){
		$url = $this->config["BT_PANEL"].$this->config["WebToBackup"];
		$p_data = $this->GetKeyData();
		$p_data['id'] = $id;
		$result = $this->HttpPostCookie($url,$p_data);
		return $result;
	}

    /**
     * 删除网站备份
     * @param number $id 网站备份ID
     * @return array|string
     */
	public function WebDelBackup($id){
		$url = $this->config["BT_PANEL"].$this->config["WebDelBackup"];
		$p_data = $this->GetKeyData();
		$p_data['id'] = $id;
		$result = $this->HttpPostCookie($url,$p_data);
		return $result;
	}

    /**
     * 删除数据库备份
     * @param $id [type] 数据库备份ID
     * @return array|string
     */
	public function SQLDelBackup($id){
		$url = $this->config["BT_PANEL"].$this->config["SQLDelBackup"];
		$p_data = $this->GetKeyData();
		$p_data['id'] = $id;
		$result = $this->HttpPostCookie($url,$p_data);
		return $result;
	}

    /**
     * 备份数据库
     * @param $id [type] 数据库列表ID
     * @return array|string
     */
	public function SQLToBackup($id){
		$url = $this->config["BT_PANEL"].$this->config["SQLToBackup"];
		$p_data = $this->GetKeyData();
		$p_data['id'] = $id;
		$result = $this->HttpPostCookie($url,$p_data);
		return $result;
	}

    /**
     * 获取网站域名列表
     * @param $id [type] 网站ID
     * @param bool $list 固定传true
     * @return array|string
     */
	public function WebDoaminList($id,$list=true){
		$url = $this->config["BT_PANEL"].$this->config["WebDoaminList"];
		$p_data = $this->GetKeyData();
		$p_data['search'] = $id;
		$p_data['list'] = $list;
		$result = $this->HttpPostCookie($url,$p_data);
		return $result;
	}

    /**
     * 添加域名
     * @param $id [type] 网站ID
     * @param $webname [type] 网站名称
     * @param $domain [type] 要添加的域名:端口 80 端品不必构造端口,多个域名用换行符隔开
     * @return array|string
     */
	public function WebAddDomain($id,$webname,$domain){
		$url = $this->config["BT_PANEL"].$this->config["WebAddDomain"];
		$p_data = $this->GetKeyData();
		$p_data['id'] = $id;
		$p_data['webname'] = $webname;
		$p_data['domain'] = $domain;
		$result = $this->HttpPostCookie($url,$p_data);
		return $result;
	}

    /**
     * 删除网站域名
     * @param $id [type] 网站ID
     * @param $webname [type] 网站名
     * @param $domain [type] 网站域名
     * @param $port [type] 网站域名端口
     * @return array|string
     */
	public function WebDelDomain($id,$webname,$domain,$port){
		$url = $this->config["BT_PANEL"].$this->config["WebDelDomain"];
		$p_data = $this->GetKeyData();
		$p_data['id'] = $id;
		$p_data['webname'] = $webname;
		$p_data['domain'] = $domain;
		$p_data['port'] = $port;
		$result = $this->HttpPostCookie($url,$p_data);
		return $result;
	}

    /**
     * 获取可选的预定义伪静态列表
     * @param $siteName [type] 网站名
     * @return array|string
     */
	public function GetRewriteList($siteName){
		$url = $this->config["BT_PANEL"].$this->config["GetRewriteList"];
		$p_data = $this->GetKeyData();
		$p_data['siteName'] = $siteName;
		$result = $this->HttpPostCookie($url,$p_data);
		return $result;
	}

	/**
	 * 获取预置伪静态规则内容（文件内容）
	 * @param [type] $path 规则名
	 * @param [type] $type 0->获取内置伪静态规则；1->获取当前站点伪静态规则
	 */
    /**
     * 获取预置伪静态规则内容（文件内容）
     * @param $path [type]规则名
     * @param int $type 0->获取内置伪静态规则；1->获取当前站点伪静态规则
     * @return array|string
     */
	public function GetFileBody($path,$type=0){
		$url = $this->config["BT_PANEL"].$this->config["GetFileBody"];
		$p_data = $this->GetKeyData();
		$path_dir = $type?'vhost/rewrite':'rewrite/nginx';
		//获取当前站点伪静态规则
		///www/server/panel/vhost/rewrite/user_hvVBT_1.test.com.conf
		//获取内置伪静态规则
		///www/server/panel/rewrite/nginx/EmpireCMS.conf
		//保存伪静态规则到站点
		///www/server/panel/vhost/rewrite/user_hvVBT_1.test.com.conf
		///www/server/panel/rewrite/nginx/typecho.conf
		$p_data['path'] = '/www/server/panel/'.$path_dir.'/'.$path.'.conf';
		//var_dump($p_data['path']);
		$result = $this->HttpPostCookie($url,$p_data);
		return $result;
	}

    /**
     * 保存伪静态规则内容(保存文件内容)
     * @param $path [type] 规则名
     * @param $data [type] 规则内容
     * @param string $encoding 规则编码强转utf-8
     * @param int $type 0->系统默认路径；1->自定义全路径
     * @return array|string
     */
	public function SaveFileBody($path,$data,$encoding='utf-8',$type=0){
		$url = $this->config["BT_PANEL"].$this->config["SaveFileBody"];
		if($type){
			$path_dir = $path;
		}else{
			$path_dir = '/www/server/panel/vhost/rewrite/'.$path.'.conf';
		}
		$p_data = $this->GetKeyData();
		$p_data['path'] = $path_dir;
		$p_data['data'] = $data;
		$p_data['encoding'] = $encoding;
		$result = $this->HttpPostCookie($url,$p_data);
		return $result;
	}

    /**
     * 设置密码访问网站
     * @param $id [type] 网站ID
     * @param $username [type] 用户名
     * @param $password [type] 密码
     * @return array|string
     */
	public function SetHasPwd($id,$username,$password){
		$url = $this->config["BT_PANEL"].$this->config["SetHasPwd"];
		$p_data = $this->GetKeyData();
		$p_data['id'] = $id;
		$p_data['username'] = $username;
		$p_data['password'] = $password;
		$result = $this->HttpPostCookie($url,$p_data);
		return $result;
	}

    /**
     * 关闭密码访问网站
     * @param $id [type] 网站ID
     * @return array|string
     */
	public function CloseHasPwd($id){
		$url = $this->config["BT_PANEL"].$this->config["CloseHasPwd"];
		$p_data = $this->GetKeyData();
		$p_data['id'] = $id;
		$result = $this->HttpPostCookie($url,$p_data);
		return $result;
	}

    /**
     * 获取网站日志
     * @param $site [type] 网站名
     * @return array|string
     */
	public function GetSiteLogs($site){
		$url = $this->config["BT_PANEL"].$this->config["GetSiteLogs"];
		$p_data = $this->GetKeyData();
		$p_data['siteName'] = $site;
		$result = $this->HttpPostCookie($url,$p_data);
		return $result;
	}

    /**
     * 获取网站盗链状态及规则信息
     * @param $id [type] 网站ID
     * @param $site [type] 网站名
     * @return array|string
     */
	public function GetSecurity($id,$site){
		$url = $this->config["BT_PANEL"].$this->config["GetSecurity"];
		$p_data = $this->GetKeyData();
		$p_data['id'] = $id;
		$p_data['name'] = $site;
		$result = $this->HttpPostCookie($url,$p_data);
		return $result;
	}

    /**
     * 设置网站盗链状态及规则信息
     * @param $id [type] 网站ID
     * @param $site [type] 网站名
     * @param $fix [type] URL后缀
     * @param $domains [type] 许可域名
     * @param $status [type] 状态
     * @return array|string
     */
	public function SetSecurity($id,$site,$fix,$domains,$status){
		$url = $this->config["BT_PANEL"].$this->config["SetSecurity"];
		$p_data = $this->GetKeyData();
		$p_data['id'] = $id;
		$p_data['name'] = $site;
		$p_data['fix'] = $fix;
		$p_data['domains'] = $domains;
		$p_data['status'] = $status;
		$result = $this->HttpPostCookie($url,$p_data);
		return $result;
	}

    /**
     * 获取网站三项配置开关（防跨站、日志、密码访问）
     * @param $id [type] 网站ID
     * @param $path [type] 网站运行目录
     * @return array|string
     */
	public function GetDirUserINI($id,$path){
		$url = $this->config["BT_PANEL"].$this->config["GetDirUserINI"];
		$p_data = $this->GetKeyData();
		$p_data['id'] = $id;
		$p_data['path'] = $path;
		$result = $this->HttpPostCookie($url,$p_data);
		return $result;
	}


    /**
     * 开启强制HTTPS
     * @param $site [type] 网站域名（纯域名）
     * @return bool|string
     */
	public function HttpToHttps($site){
		$url = $this->config["BT_PANEL"].$this->config["HttpToHttps"];
		$p_data = $this->GetKeyData();
		$p_data['siteName'] = $site;
		$result = $this->HttpPostCookie($url,$p_data);
		return $result;
	}

    /** 关闭强制HTTPS
     * @param $site [type] 域名(纯域名)
     * @return bool|string
     */
	public function CloseToHttps($site){
		$url = $this->config["BT_PANEL"].$this->config["CloseToHttps"];
		$p_data = $this->GetKeyData();
		$p_data['siteName'] = $site;
		$result = $this->HttpPostCookie($url,$p_data);
		return $result;
	}

    /**
     * 设置SSL域名证书
     * @param $type [type] 类型
     * @param $site [type] 网站名
     * @param $key [type] 证书key
     * @param $csr [type] 证书PEM
     * @return bool|string
     */
	public function SetSSL($type,$site,$key,$csr){
		$url = $this->config["BT_PANEL"].$this->config["SetSSL"];
		$p_data = $this->GetKeyData();
		$p_data['type'] = $type;
		$p_data['siteName'] = $site;
		$p_data['key'] = $key;
		$p_data['csr'] = $csr;
		$result = $this->HttpPostCookie($url,$p_data);
		return $result;

	}

    /**
     * 关闭SSL
     * @param $updateOf [type] 修改状态码
     * @param $site [type] 域名(纯域名)
     * @return bool|string
     */
	public function CloseSSLConf($updateOf,$site){
		$url = $this->config["BT_PANEL"].$this->config["CloseSSLConf"];
		$p_data = $this->GetKeyData();
		$p_data['updateOf'] = $updateOf;
		$p_data['siteName'] = $site;
		$result = $this->HttpPostCookie($url,$p_data);
		return $result;
	}

    /**
     * 获取SSL状态及证书信息
     * @param $site [type] 域名（纯域名）
     * @return bool|string
     */
	public function GetSSL($site){
		$url = $this->config["BT_PANEL"].$this->config["GetSSL"];
		$p_data = $this->GetKeyData();
		$p_data['siteName'] = $site;
		$result = $this->HttpPostCookie($url,$p_data);
		return $result;
	}

    /**
     * 获取网站默认文件
     * @param $id [type] 网站ID
     * @return bool|string
     */
	public function WebGetIndex($id){
		$url = $this->config["BT_PANEL"].$this->config["WebGetIndex"];
		$p_data = $this->GetKeyData();
		$p_data['id'] = $id;
		$result = $this->HttpPostCookie($url,$p_data);
		return $result;
	}

    /**
     * 设置网站默认文件
     * @param $id    [type] 网站ID
     * @param $index [type] 内容
     * @return bool|string
     */
	public function WebSetIndex($id,$index){
		$url = $this->config["BT_PANEL"].$this->config["WebSetIndex"];
		$p_data = $this->GetKeyData();
		$p_data['id'] = $id;
		$p_data['Index'] = $index;
		$result = $this->HttpPostCookie($url,$p_data);
		return $result;
	}

    /**
     * 获取网站流量限制信息
     * @param $id [type] [description]
     * @return bool|string
     */
	public function GetLimitNet($id){
		$url = $this->config["BT_PANEL"].$this->config["GetLimitNet"];
		$p_data = $this->GetKeyData();
		$p_data['id'] = $id;
		$result = $this->HttpPostCookie($url,$p_data);
		return $result;
	}

    /**
     * @param $id         [type] 网站ID
     * @param $perserver  [type] 并发限制
     * @param $perip      [type] 单IP限制
     * @param $limit_rate [type] 流量限制
     * @return bool|string
     */
	public function SetLimitNet($id,$perserver,$perip,$limit_rate){
		$url = $this->config["BT_PANEL"].$this->config["SetLimitNet"];
		$p_data = $this->GetKeyData();
		$p_data['id'] = $id;
		$p_data['perserver'] = $perserver;
		$p_data['perip'] = $perip;
		$p_data['limit_rate'] = $limit_rate;
		$result = $this->HttpPostCookie($url,$p_data);
		return $result;
	}

    /**
     * 关闭网站流量限制
     * @param $id [type] 网站ID
     * @return bool|string
     */
	public function CloseLimitNet($id){
		$url = $this->config["BT_PANEL"].$this->config["CloseLimitNet"];
		$p_data = $this->GetKeyData();
		$p_data['id'] = $id;
		$result = $this->HttpPostCookie($url,$p_data);
		return $result;
	}

    /**
     * 获取网站301重定向信息
     * @param $site [type] 网站名
     * @return bool|string
     */
	public function Get301Status($site){
		$url = $this->config["BT_PANEL"].$this->config["Get301Status"];
		$p_data = $this->GetKeyData();
		$p_data['siteName'] = $site;
		$result = $this->HttpPostCookie($url,$p_data);
		return $result;
	}

    /**
     * @param $site      [type] 网站名
     * @param $toDomain  [type] 目标Url
     * @param $srcDomain [type] 来自Url
     * @param $type      [type] 类型
     * @return bool|string
     */
	public function Set301Status($site,$toDomain,$srcDomain,$type){
		$url = $this->config["BT_PANEL"].$this->config["Set301Status"];
		$p_data = $this->GetKeyData();
		$p_data['siteName'] = $site;
		$p_data['toDomain'] = $toDomain;
		$p_data['srcDomain'] = $srcDomain;
		$p_data['type'] = $type;
		$result = $this->HttpPostCookie($url,$p_data);
		return $result;
	}

    /**
     * 获取网站反代信息及状态
     * @param $site [type] [description]
     * @return bool|string
     */
	public function GetProxyList($site){
		$url = $this->config["BT_PANEL"].$this->config["GetProxyList"];
		$p_data = $this->GetKeyData();
		$p_data['sitename'] = $site;
		$result = $this->HttpPostCookie($url,$p_data);
		return $result;
	}

    /**
     * @param $cache     [type] 是否缓存
     * @param $proxyname [type] 代理名称
     * @param $cachetime [type] 缓存时长 /小时
     * @param $proxydir  [type] 代理目录
     * @param $proxysite [type] 反代URL
     * @param $todomain  [type] 目标域名
     * @param $advanced  [type] 高级功能：开启代理目录
     * @param $sitename  [type] 网站名
     * @param $subfilter [type] 文本替换json格式[{"sub1":"百度","sub2":"白底"},{"sub1":"","sub2":""}]
     * @param $type      [type] 开启或关闭 0关;1开
     * @return bool|string
     */
	public function CreateProxy($cache,$proxyname,$cachetime,$proxydir,$proxysite,$todomain,$advanced,$sitename,$subfilter,$type){
		$url = $this->config["BT_PANEL"].$this->config["CreateProxy"];
		$p_data = $this->GetKeyData();
		$p_data['cache'] = $cache;
		$p_data['proxyname'] = $proxyname;
		$p_data['cachetime'] = $cachetime;
		$p_data['proxydir'] = $proxydir;
		$p_data['proxysite'] = $proxysite;
		$p_data['todomain'] = $todomain;
		$p_data['advanced'] = $advanced;
		$p_data['sitename'] = $sitename;
		$p_data['subfilter'] = $subfilter;
		$p_data['type'] = $type;
		$result = $this->HttpPostCookie($url,$p_data);
		return $result;
	}

    /**
     * @param $cache     [type]是否缓存
     * @param $proxyname [type] 代理名称
     * @param $cachetime [type] 缓存时长 /小时
     * @param $proxydir  [type] 代理目录
     * @param $proxysite [type] 反代URL
     * @param $todomain  [type] 目标域名
     * @param $advanced  [type] 高级功能：开启代理目录
     * @param $sitename  [type] 网站名
     * @param $subfilter [type] 文本替换json格式[{"sub1":"百度","sub2":"白底"},{"sub1":"","sub2":""}]
     * @param $type      [type] 开启或关闭 0关;1开
     * @return bool|string
     */
	public function ModifyProxy($cache,$proxyname,$cachetime,$proxydir,$proxysite,$todomain,$advanced,$sitename,$subfilter,$type){
		$url = $this->config["BT_PANEL"].$this->config["ModifyProxy"];
		$p_data = $this->GetKeyData();
		$p_data['cache'] = $cache;
		$p_data['proxyname'] = $proxyname;
		$p_data['cachetime'] = $cachetime;
		$p_data['proxydir'] = $proxydir;
		$p_data['proxysite'] = $proxysite;
		$p_data['todomain'] = $todomain;
		$p_data['advanced'] = $advanced;
		$p_data['sitename'] = $sitename;
		$p_data['subfilter'] = $subfilter;
		$p_data['type'] = $type;
		$result = $this->HttpPostCookie($url,$p_data);
		return $result;
	}

    /**
     * 获取网站域名绑定二级目录信息
     * @param $id [type] 网站ID
     * @return bool|string
     */
	public function GetDirBinding($id){
		$url = $this->config["BT_PANEL"].$this->config["GetDirBinding"];
		$p_data = $this->GetKeyData();
		$p_data['id'] = $id;
		$result = $this->HttpPostCookie($url,$p_data);
		return $result;
	}

    /**
     * @param $id      [type] 网站ID
     * @param $domain  [type] 域名
     * @param $dirName [type] 目录
     * @return bool|string
     */
	public function AddDirBinding($id,$domain,$dirName){
		$url = $this->config["BT_PANEL"].$this->config["AddDirBinding"];
		$p_data = $this->GetKeyData();
		$p_data['id'] = $id;
		$p_data['domain'] = $domain;
		$p_data['dirName'] = $dirName;
		$result = $this->HttpPostCookie($url,$p_data);
		return $result;
	}
	
    /**
     * 删除网站域名绑定二级目录
     * @param $dirid [type] 子目录ID
     * @return mixed
     */
	public function DelDirBinding($dirid){
		$url = $this->config["BT_PANEL"].$this->config["DelDirBinding"];
		$p_data = $this->GetKeyData();
		$p_data['id'] = $dirid;
		$result = $this->HttpPostCookie($url,$p_data);
		return $result;
	}

    /**
     * 获取网站子目录绑定伪静态信息
     * @param $dirid [type] 子目录绑定ID
     * @param int $type
     * @return bool|string
     */
	public function GetDirRewrite($dirid,$type=0){
		$url = $this->config["BT_PANEL"].$this->config["GetDirRewrite"];
		$p_data = $this->GetKeyData();
		$p_data['id'] = $dirid;
		if($type){
			$p_data['add'] = 1;
		}
		$result = $this->HttpPostCookie($url,$p_data);
		return $result;
	}

    /**
     * 修改FTP账号密码
     * @param $id           [type] FTP_ID
     * @param $ftp_username [type] 用户名
     * @param $new_password [type] 密码
     * @return mixed
     */
	public function SetUserPassword($id,$ftp_username,$new_password){
		$url = $this->config["BT_PANEL"].$this->config["SetUserPassword"];
		$p_data = $this->GetKeyData();
		$p_data['id'] = $id;
		$p_data['ftp_username'] = $ftp_username;
		$p_data['new_password'] = $new_password;
		$result = $this->HttpPostCookie($url,$p_data);
		return $result;
	}

    /**
     * 修改SQL账号密码
     * @param $id       [type] SQL_ID
     * @param $name     [type] 用户名
     * @param $password [type] 密码
     * @return mixed
     */
	public function ResDatabasePass($id,$name,$password){
		$url = $this->config["BT_PANEL"].$this->config["ResDatabasePass"];
		$p_data = $this->GetKeyData();
		$p_data['id'] = $id;
		$p_data['name'] = $name;
		$p_data['password'] = $password;
		$result = $this->HttpPostCookie($url,$p_data);
		return $result;
	}

    /**
     * 启用/禁用FTP
     * @param $id       [type] FTPID
     * @param $username [type] 用户名
     * @param $status   [type] 状态 0->关闭;1->开启
     * @return mixed
     */
	public function SetStatus($id,$username,$status){
		$url = $this->config["BT_PANEL"].$this->config["SetStatus"];
		$p_data = $this->GetKeyData();
		$p_data['id'] = $id;
		$p_data['username'] = $username;
		$p_data['status'] = $status;
		$result = $this->HttpPostCookie($url,$p_data);
		return $result;
	}

    /**
     * 宝塔一键部署列表
     * @param string $search 搜索关键词
     * @return mixed  [type] [description]
     */
	public function deployment($search=''){
		if($search){
			$url = $this->config["BT_PANEL"].$this->config["deployment"].'&search='.$search;
		}else{
			$url = $this->config["BT_PANEL"].$this->config["deployment"];
		}
		$p_data = $this->GetKeyData();
		$result = $this->HttpPostCookie($url,$p_data);
		return $result;
	}

    /**
     * 宝塔一键部署执行
     * @param $dname       [type] 部署程序名
     * @param $site_name   [type] 部署到网站名
     * @param $php_version [type] PHP版本
     * @return mixed
     */
	public function SetupPackage($dname,$site_name,$php_version){
		$url = $this->config["BT_PANEL"].$this->config["SetupPackage"];
		$p_data = $this->GetKeyData();
		$p_data['dname'] = $dname;
		$p_data['site_name'] = $site_name;
		$p_data['php_version'] = $php_version;
		$result = $this->HttpPostCookie($url,$p_data);
		return $result;
	}

    /**
     * 构造带有签名的关联数组
     * @return array
     */
	public function GetKeyData(){
		$now_time = time();
		$p_data = array('request_token'	=>md5($now_time.''.md5($this->config["BT_KEY"])),'request_time'=>$now_time);
		return $p_data;
	}

	/**
     * 发起POST请求
     * @param String $url 目标网填，带http://
     * @param array|String $data 提交的数据
     * @param int $timeout
     * @return array|string
     */
	private function HttpPostCookie($url,$data,$timeout = 60){
        if(!$this->config["BT_PANEL"])return array("code"=>0,"msg"=>"配置的面板地址错误，或并没有配置");
        if(!$this->config["BT_KEY"])return array("code"=>0,"msg"=>"配置的密钥错误或并没有配置");
    	//定义cookie保存位置
		$cookie_file='./'.md5($this->config["BT_PANEL"]).'.cookie';
		if(!file_exists($cookie_file)){
			$fp = fopen($cookie_file,'w+');
			fclose($fp);
		}
		$ch = curl_init();
		curl_setopt($ch, CURLOPT_URL, $url);
		curl_setopt($ch, CURLOPT_TIMEOUT, $timeout);
		curl_setopt($ch, CURLOPT_POST, 1);
		curl_setopt($ch, CURLOPT_POSTFIELDS, $data);
		curl_setopt($ch, CURLOPT_COOKIEJAR, $cookie_file);
		curl_setopt($ch, CURLOPT_COOKIEFILE, $cookie_file);
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
		curl_setopt($ch, CURLOPT_HEADER, 0);
		curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, false);
		curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
		$output = curl_exec($ch);
        $status = curl_getinfo($ch);
		curl_close($ch);
        if(!isset($status['http_code']) && $status['http_code'] != 200)return array("code"=>0,"msg"=>"访问失败，请确保信息正常");
        $Result=json_decode($this->modifyCode($output),true);
        if(!$Result)return array("code"=>0,"msg"=>"json转换失败，请程序猿检查详细问题");
        return array("code"=>1,"msg"=>"访问成功","result"=>$Result);
	}

    /**
     * 修改编码
     * @param $content
     * @return false|mixed|string
     */
	private function modifyCode($content){
        $encode_arr = array('UTF-8','ASCII','GBK','GB2312','BIG5','JIS','eucjp-win','sjis-win','EUC-JP');
        $encoded = mb_detect_encoding($content,$encode_arr);
        $content = iconv($encoded,$this->config["ENCODE"],$content);
        $content = str_replace(array("\r\n", "\r", "\n"),"",$content);
        return $content;
    }
}